#!/usr/bin/env python

import matplotlib
#matplotlib.use("Qt4Agg")
import matplotlib.pyplot as plt
import numpy as np

import sys

import performance_plot
import runtime_plot

from plot_common import GlobFile, models, PerfRun

methods = ["btree", "dithering", "random", "mrfz+foe", "mrfz+pw"]

image = "lena-171"

# create precision measure plots
data = GlobFile(image+"/results.txt")

measures = [("psnr", 40), ("ssim", 1)]            # (name, ylimit)
qs = ["0.2", "0.05", "0.02"]

# create method overview
for model in ["3x3_foe", "pw_mrf"]:
    for ms in measures:
        line_plts = [m+"*"+model+"*" for m in methods]+["jp2_*"]
        dat = [[PerfRun(l) for l in data.filter(g)] for g in line_plts]
        performance_plot.line_plot(image, model, dat, *ms, model=False)

# create compression ratio plots
for ms in measures:
    for q in qs:
        dat = [PerfRun(l) for l in data.filter("*_"+q+"*")]                
        performance_plot.plot(image, q, dat, *ms)

# create model overview plots
for ms in measures:
    for m in ["mrfz+foe"]:
        line_plts = ["jp2_*", m+"*linear*", m+"*pw_mrf*", m+"*3x3_foe*"]
        dat = [[PerfRun(l) for l in data.filter(g)] for g in line_plts]
        performance_plot.line_plot(image, m, dat, *ms)

# create runtime plot
tdata = GlobFile("../output/"+image+"/runtimes.txt")
times = [[l for l in tdata.filter("*"+m+"*")] for m in models[:-2]]

runtime_plot.plot(image, models, times)
