from plot_common import *

import matplotlib
import matplotlib.pyplot as plt
import numpy as np

from plot_common import colors, models, ftype

def get_color(model):    
    return colors[models.index(model)]

def line_plot(image, method, data, measure, ylim, model=True):    
    # do the plotting
    f = plt.figure(1)
    f.clf()
    plt.ylim([0, ylim])
    plt.ylabel(measure)
    
    plt.xlim([0, 0.25])
    plt.xlabel("compression ratio")
    
    lbl = []
    res = []
    
    for i in xrange(len(data)):
        x = [d.q for d in data[i]]
        y = [getattr(d, measure) for d in data[i]]
        c = get_color(data[i][0].model) if model else colors[i]
        r = plt.plot(x, y, "-", color=c)
        res.append(r)
        lbl.append(data[i][0].model if model else data[i][0].method)
        
    
    plt.title(image+" "+method)
    
    plt.legend(res, lbl, loc=4)
    
    #plt.show()
    plt.savefig(image+"/"+method+"-"+measure+ftype)

def plot(image, q, data, measure, ylim):
    width = 0.8
    
    keyfun = lambda o: getattr(o, measure)
    
    data.sort(key=keyfun, reverse=True)
    
    xticks = [d.method for d in data]
    vals = [keyfun(d) for d in data]
    colors = [get_color(d.model) for d in data]
    
    idx = np.arange(len(xticks))
    
    # do the plotting
    f = plt.figure(1)
    f.clf()
    plt.ylim([0, ylim])
    rects = plt.bar(idx, vals, width=width, color=colors)
    
    legend = []
    rects2 = []
    
    for i in xrange(len(data)):
        if "jp2" == data[i].method:
            continue
                
        if data[i].model not in legend:
            legend.append(data[i].model)
            rects2.append(rects[i])
        
    plt.legend(rects2, legend)
    plt.xticks(idx+width, xticks)
    f.autofmt_xdate(rotation=45, bottom=0.24)
    plt.ylabel(measure)
    plt.title(image+" "+str(q)+" "+measure)
    #plt.show()
    plt.savefig(image+"/"+str(q)+"-"+measure+ftype)
