import fnmatch

colors = ["#F2C432", "#3A5454", "#C24C1E", "#572F13", "#736E1E", "#FF0000"]
models = ["pw_mrf", "3x3_foe", "linear", "jp2"]

ftype = ".pdf"

class Run:
    def __init__(self, descr):
        try:
            methodq, self.model = descr.split("-")
        except ValueError:
            methodq = descr
            self.model = "jp2"
            
        self.method, q = methodq.split("_")
        
        self.q = float(q)

class PerfRun(Run):
    def __init__(self, line):
        descr, psnr, ssim = line.split(" ")
        Run.__init__(self, descr)
        
        self.psnr = float(psnr)
        self.ssim = float(ssim)

class GlobFile:
    def __init__(self, filename):
        f = file(filename)
        self._data = f.readlines()
        f.close()
        
        self._data = [l for l in self._data if not l.startswith("#")] # skip comments
    
    def filter(self, pattern):
        return fnmatch.filter(self._data, pattern)
    
    def sorted(self, pattern, measure):
        t = [PerfRun(l) for l in self.filter(pattern)]
        
        return sorted(t, key=lambda o: getattr(o, measure), reverse=True)
    
    def methods(self):
        return list(set([l.split("_")[0] for l in self._data]))