function [mask name] = mask_btree(img, percent)
    sz = size(img);
    mask = zeros(sz);
    
    javaaddpath('.');
    
    q = java.util.PriorityQueue(10, MatlabComparator());
    %q = java.util.LinkedList();
    
    pts = [1 1; 1 sz(2); sz(1) sz(2)];
    q.add({variance(pts, img), pts});
    pts = [1 1; sz(1) 1; sz(1) sz(2)];
    q.add({variance(pts, img), pts});
    
    % BFS
    while q.size() > 0
        r = q.remove();
        var = r(1);
        pts = r(2);
        
        for i = 1:3
            mask(pts(i,1), pts(i,2)) = 1; % mark pixel as part of mask
        end
        
        if sum(sum(mask))/numel(img) >= percent
            break
        end
        
        % decide whether current triangle should be split
        if true%var > 255/10
            % hypotenuse is assumed to be between pts(1) and pts(3)
            % 90° at pts(2)
            sp = round((pts(1,:) + pts(3,:))/2); % split point

            if ~big_enough(pts, sp)
                continue;
            end
            
            npts = [pts(1,:); sp; pts(2,:)];
            q.add({variance(npts, img), npts});
            
            npts = [pts(2,:); sp; pts(3,:)];
            q.add({variance(npts, img), npts});
        end
    end
    
    %p = sum(sum(mask))/numel(img);
    name = ['btree_' num2str(percent)];
    
    p = sum(sum(mask))/numel(img)
    
    % ones(white) are being inpainted  
    mask = ~logical(mask);
end

% checks whether new triangle will be at least
% 1px big along each axis
function b = big_enough(pts, sp)
    b = true;
    for i = 1:3
        if sum(abs(pts(i,:)-sp)) < 2
            b = false;
            return
        end
    end
end

function a = tri_area(pts)
    mn = min(pts);
    mx = max(pts);
    
    a = prod(mx-mn)/2;
end

function sigma = variance(pts, img)
    mn = min(pts);
    mx = max(pts);
    
    sub = img(mn(1):mx(1), mn(2):mx(2));
    
    if(pts(1,1) == pts(2,1) && pts(2,2) == pts(3,2))
        if(pts(1,2) < pts(2,2))
            sub = sub';
        end
        
        elts = sub(tril(sub) > 0);
    elseif(pts(1,2) == pts(2,2) && pts(2,1) == pts(3,1))
        if(pts(2,2) < pts(3,2))
            sub = sub';
        end
        
        elts = sub(triu(sub) > 0);
    else
        elts = sub(:);
    end
    
    sigma = var(elts)*tri_area(pts);
end