import glob
import sys
import os.path

image = "lena-171"
scale = "0.65"
compressed_dir = "../output/"+image+"/"

f = file("images.tex", "w")
#f = sys.stdout

mcompress = ["random", "mrfz+foe", "dithering", "btree"]
mdecompress = ["linear", "pw_mrf", "3x3_foe"]

de2hr = {"linear": "Linear", "pw_mrf": "Pairwise MRFs", "3x3_foe": "3x3 Field of Experts"}

def write_title(title):
    f.write((r"\subsection{%s}" % title)+"\n\n")

def write_decompress_comparison(rows, q=None):
    ncols = len(mcompress)
    f.write(r"\begin{tabular}{"+("c"*ncols)+"}"+"\n")
    f.write((r"\includegraphics[scale=%s]{%soriginal.png} &" % (scale, compressed_dir))+"\n")
    
    if q is not None:
        f.write((r"\includegraphics[scale=%s]{{%sjp2_%s}.png}" % (scale, compressed_dir, q)))
        
    f.write(r"\\"+"\n")
    
    header = [r"\textbf{%s}" % c for c in mcompress]
    header = " & ".join(header)+r"\\"
    
    f.write(header+"\n")
    f.write(r"\hline"+"\n")
    
    for rtitle, imgs in rows:
        f.write((r"\multicolumn{%d}{l}{%s}\\" % (ncols, rtitle))+"\n")
        imgs = [r"\includegraphics[scale=%s]{{%s}%s}" % tuple([scale]+list(os.path.splitext(i))) for i in imgs]
        f.write(" &\n".join(imgs))
        f.write(r" \\"+"\n")
    
    f.write(r"\end{tabular}"+"\n")
    f.write("\n")

def get_imgs(q, mdecompress):
    pattern = "*%s-%s.png" % (q, mdecompress)
    imgs = []
    
    for m in mcompress:
        imgs += glob.glob(compressed_dir+m+pattern)
        
    imgs = sorted(imgs, reverse=True)
    return imgs

def write_overview_at(q):
    write_title("Overview at q = %s" %q)
    rows = [(de2hr[m], get_imgs(q, m)) for m in mdecompress]
    write_decompress_comparison(rows, q)
    
#write_title("Pairwise MRF")
#write_decompress_comparison([("q = 0.2", "*0.2-pw_mrf.png"), ("q = 0.02", "*0.02-pw_mrf.png")])

#write_title("3x3 Field Of Experts")
#write_decompress_comparison([("q = 0.2", "*0.2-3x3_foe.png"), ("q = 0.02", "*0.02-3x3_foe.png")])

write_overview_at("0.2")
write_overview_at("0.05")
#write_overview_at("0.02")

#write_decompress_comparison([("Btree (q = 0.2)", "btree*0.2-pw_mrf.png"),("Btree (q = 0.02)", "btree*0.02-pw_mrf.png")])
